@@ -5,10 +5,12 @@
 mod error;
 mod error_3rd;
 
-pub use self::error::{MaybeRanged, Result, DokiError, DokiErrorKind};
+pub use self::error::{DokiError, DokiErrorKind, MaybeRanged, Result};
 pub use url::Url;
 pub use yggdrasil_shared::DiagnosticLevel;
 
+#[cfg(feature = "config")]
+pub extern crate config;
 #[cfg(feature = "git2")]
 pub extern crate git2;
 #[cfg(feature = "globset")]
